@@ -358,6 +358,34 @@ impl ConcreteEvent for LostPointerCaptureEvent {
     const EVENT_TYPE: &'static str = "lostpointercapture";
 }
 
+/// The `PointerLockChangeEvent` fires when the pointer is locked or unlocked
+///
+/// [(JavaScript docs)](https://developer.mozilla.org/en-US/docs/Web/Events/pointerlockchange)
+// http://www.w3.org/TR/pointerlock/#pointerlockchange-and-pointerlockerror-events
+#[derive(Clone, Debug, PartialEq, Eq, ReferenceType)]
+#[reference(instance_of = "Event")] // TODO: Better type check.
+#[reference(subclass_of(Event))]
+pub struct PointerLockChangeEvent( Reference );
+
+impl IEvent for PointerLockChangeEvent {}
+impl ConcreteEvent for PointerLockChangeEvent {
+    const EVENT_TYPE: &'static str = "pointerlockchange";
+}
+
+/// The `PointerLockErrorEvent` fires when an error occurs locking a pointer
+///
+/// [(JavaScript docs)](https://developer.mozilla.org/en-US/docs/Web/Events/pointerlockerror)
+// http://www.w3.org/TR/pointerlock/#pointerlockchange-and-pointerlockerror-events
+#[derive(Clone, Debug, PartialEq, Eq, ReferenceType)]
+#[reference(instance_of = "Event")] // TODO: Better type check.
+#[reference(subclass_of(Event))]
+pub struct PointerLockErrorEvent( Reference );
+
+impl IEvent for PointerLockErrorEvent {}
+impl ConcreteEvent for PointerLockErrorEvent {
+    const EVENT_TYPE: &'static str = "pointerlockerror";
+}
+
 #[cfg(all(test, feature = "web_test"))]
 mod tests {
     use super::*;
@@ -488,4 +516,20 @@ mod tests {
         ).try_into().unwrap();
         assert_eq!( event.event_type(), LostPointerCaptureEvent::EVENT_TYPE );
     }
+
+    #[test]
+    fn test_pointer_lock_change_event() {
+        let event: PointerLockChangeEvent = js!(
+            return new Event( @{PointerLockChangeEvent::EVENT_TYPE} );
+        ).try_into().unwrap();
+        assert_eq!( event.event_type(), PointerLockChangeEvent::EVENT_TYPE );
+    }
+
+    #[test]
+    fn test_pointer_lock_error_event() {
+        let event: PointerLockErrorEvent = js!(
+            return new Event( @{PointerLockErrorEvent::EVENT_TYPE} );
+        ).try_into().unwrap();
+        assert_eq!( event.event_type(), PointerLockErrorEvent::EVENT_TYPE );
+    }
 }
