@@ -38,3 +38,6 @@ pub mod console;
 pub mod html_collection;
 pub mod child_node;
 pub mod gamepad;
+
+#[cfg(feature = "futures-support")]
+pub mod timer_future;
